<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../ui/AboutDialog.ui" line="14"/>
        <source>About Scan Tailor</source>
        <translation>À propos de Scan Tailor</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="27"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <source>Scan Tailor is an interactive post-processing tool for scanned pages. It performs operations such as page splitting, skew correction, adding/removing margins, and others. You give it raw scans, and you get pages ready to be printed or assembled into a PDF or DJVU file.  Scanning and optical character recogrnition is out of scope of this project.</source>
        <translation type="obsolete">Scan Tailor est un logiciel de post-traitement de pages scannées. Il permet de scinder les pages, de les redresser, d&apos;ajouter ou supprimer des marges, etc. Vous chargez des scans bruts et vous obtenez des pages prêtes à être imprimées ou assemblées en un fichier PDF ou DJVU. La numérisation des pages et l&apos;OCR ne font pas parti de ce projet.</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="33"/>
        <source>Scan Tailor is an interactive post-processing tool for scanned pages. It performs operations such as page splitting, skew correction, adding/removing margins, and others. You give it raw scans, and you get pages ready to be printed or assembled into a PDF or DJVU file.  Scanning and optical character recognition is out of scope of this project.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="101"/>
        <source>Authors</source>
        <translation>Auteurs</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="125"/>
        <source>Lead Developer</source>
        <translation>Programmeur Principal</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="132"/>
        <source>Joseph Artsimovich</source>
        <translation>Joseph Artsimovich</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="157"/>
        <source>U235 - Picture auto-detection algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="164"/>
        <source>Robert B. - First generation dewarping algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="171"/>
        <source>Andrey Bergman - System load adjustment.</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../ui/AboutDialog.ui" line="178"/>
        <source>Petr Kovář - Command line interface.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="205"/>
        <source>Svetoslav Sashkov, Mandor - Bulgarian</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../ui/AboutDialog.ui" line="212"/>
        <source>Petr Kovář - Czech</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="219"/>
        <source>Stefan Birkner - German</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="226"/>
        <source>Angelo Gemmi - Italian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="233"/>
        <source>Masahiro Kitagawa - Japanese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="240"/>
        <source>Patrick Pascal - French</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../ui/AboutDialog.ui" line="247"/>
        <source>Daniel Koć - Polish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="254"/>
        <source>Joseph Artsimovich - Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../ui/AboutDialog.ui" line="261"/>
        <source>Marián Hvolka - Slovak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="268"/>
        <source>Flavio Benelli - Spanish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="275"/>
        <source>Davidson Wang - Traditional Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="282"/>
        <source>Yuri Chornoivan - Ukrainian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="309"/>
        <source>denver 22</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="190"/>
        <source>Translators</source>
        <translation>Traducteurs</translation>
    </message>
    <message>
        <source>Svetoslav Sashkov, Mandor - Bulgarian
               Stefan Birkner - German
               Angelo Gemmi - Italian
               Masahiro Kitagawa - Japanese
               Patrick Pascal - French
               Joseph Artsimovich - Russian
               Davidson Wang - Traditional Chinese</source>
        <translation type="obsolete">Svetoslav Sashkov, Mandor - version bulgare
               Stefan Birkner - German
               Angelo Gemmi - Italian
               Masahiro Kitagawa - version japonaise
               Patrick Pascal - version française
               Joseph Artsimovich - version russe
               Davidson Wang - Traditional Chinese</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="142"/>
        <source>Contributors</source>
        <translation>Contributeurs</translation>
    </message>
    <message>
        <source>U235 - Picture auto-detection algorithm.
Robert B. - Dewarping algorithm.
Andrey Bergman - System load adjustment.
</source>
        <translation type="obsolete">U235 - Picture auto-detection algorithm.
Robert B. - Dewarping algorithm.
Andrey Bergman - System load adjustment.</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="294"/>
        <source>Documentation</source>
        <translation>Documentation</translation>
    </message>
    <message>
        <source>denver 22
phaedrus
Taxman</source>
        <translation type="obsolete">denver 22
phaedrus
Taxman</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="350"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
</context>
<context>
    <name>BatchProcessingLowerPanel</name>
    <message>
        <location filename="../ui/BatchProcessingLowerPanel.ui" line="14"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../ui/BatchProcessingLowerPanel.ui" line="36"/>
        <source>Beep when finished</source>
        <translation>Bipper quand la tâche est accomplie</translation>
    </message>
</context>
<context>
    <name>ColorPickupInteraction</name>
    <message>
        <location filename="../filters/output/ColorPickupInteraction.cpp" line="47"/>
        <source>Click on an area to pick up its color, or ESC to cancel.</source>
        <translation>Cliquer sur un espace pour obtenir sa couleur, ou ECHAP pour quitter.</translation>
    </message>
</context>
<context>
    <name>DeskewApplyDialog</name>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="20"/>
        <source>Apply to</source>
        <translation type="unfinished">Appliquer à</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="26"/>
        <source>This page only (already applied)</source>
        <translation type="unfinished">Cette page uniquement (déjà appliqué)</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="36"/>
        <source>All pages</source>
        <translation type="unfinished">Toutes les pages</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="43"/>
        <source>This page and the following ones</source>
        <translation type="unfinished">Cette page et les suivantes</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="59"/>
        <source>Selected pages</source>
        <translation type="unfinished">Les pages sélectionnées</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="92"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeskewOptionsWidget</name>
    <message>
        <location filename="../filters/deskew/ui/DeskewOptionsWidget.ui" line="14"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewOptionsWidget.ui" line="20"/>
        <source>Deskew</source>
        <translation>Redresser</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewOptionsWidget.ui" line="41"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewOptionsWidget.ui" line="57"/>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewOptionsWidget.ui" line="140"/>
        <source>Apply To ...</source>
        <translation type="unfinished">Appliquer à ...</translation>
    </message>
</context>
<context>
    <name>DragHandler</name>
    <message>
        <location filename="../interaction/DragHandler.cpp" line="46"/>
        <source>Unrestricted dragging is possible by holding down the Shift key.</source>
        <translation>Un glissement sans restrictions est possible en pressant la touche majuscule.</translation>
    </message>
</context>
<context>
    <name>ErrorWidget</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Form</translation>
    </message>
    <message>
        <source>ImageLabel</source>
        <translation type="obsolete">ImageLabel</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation type="obsolete">TextLabel</translation>
    </message>
</context>
<context>
    <name>FixDpiDialog</name>
    <message>
        <source>Need Fixing</source>
        <translation type="obsolete">Réglage Nécessaire</translation>
    </message>
    <message>
        <source>All Pages</source>
        <translation type="obsolete">Toutes les pages</translation>
    </message>
    <message>
        <source>DPI is too large and most likely wrong.</source>
        <translation type="obsolete">DPI trop élevé et probablement mauvais.</translation>
    </message>
    <message>
        <source>DPI is too small. Even if it&apos;s correct, you are not going to get acceptable results with it.</source>
        <translation type="obsolete">DPI top faible. Même si c&apos;est correcte, vous n&apos;allez pas obtenir un résultat satisfaisant.</translation>
    </message>
    <message>
        <source>DPI is too small for this pixel size. Such combination would probably lead to out of memory errors.</source>
        <translation type="obsolete">DPI trop faible pour cette taille de pixel. Une telle combinaison va probablement aboutir à des erreurs de mémoire.</translation>
    </message>
    <message>
        <source>%1 (page %2)</source>
        <translation type="obsolete">%1 (page %2)</translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="13"/>
        <source>Fix DPI</source>
        <translation>Fixer le DPI</translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="23"/>
        <source>Tab 1</source>
        <translation>Tab 1</translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="33"/>
        <source>Tab 2</source>
        <translation>Tab 2</translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="46"/>
        <source>DPI</source>
        <translation>DPI</translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="69"/>
        <source>Custom</source>
        <translation>Personnaliser</translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="90"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="113"/>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
</context>
<context>
    <name>FixDpiSinglePageDialog</name>
    <message>
        <source>Fix DPI</source>
        <translation type="obsolete">Fixer le DPI</translation>
    </message>
    <message>
        <source>DPI for %1</source>
        <translation type="obsolete">DPI pour %1</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation type="obsolete">Personnaliser</translation>
    </message>
    <message>
        <source>x</source>
        <translation type="obsolete">x</translation>
    </message>
    <message>
        <source>%1 (page %2)</source>
        <translation type="obsolete">%1 (page %2)</translation>
    </message>
    <message>
        <source>DPI is too large and most likely wrong.</source>
        <translation type="obsolete">DPI trop élevé et probablement mauvais.</translation>
    </message>
    <message>
        <source>DPI is too small. Even if it&apos;s correct, you are not going to get acceptable results with it.</source>
        <translation type="obsolete">DPI top faible. Même si c&apos;est correcte, vous n&apos;allez pas obtenir un résultat satisfaisant.</translation>
    </message>
    <message>
        <source>DPI is too small for this pixel size. Such combination would probably lead to out of memory errors.</source>
        <translation type="obsolete">DPI trop faible pour cette taille de pixel. Une telle combinaison va probablement aboutir à des erreurs de mémoire.</translation>
    </message>
</context>
<context>
    <name>ImageViewBase</name>
    <message>
        <source>Use the mouse wheel or +/- to zoom.  When zoomed, dragging is possible.</source>
        <translation type="obsolete">Utilisez la molette de la souris ou + / - pour zoomer. Une fois le zoom effectué, vous pourrez glisser-déplacer l&apos;image.</translation>
    </message>
</context>
<context>
    <name>InteractiveXSpline</name>
    <message>
        <location filename="../interaction/InteractiveXSpline.cpp" line="47"/>
        <source>Click to create a new control point.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../interaction/InteractiveXSpline.cpp" line="73"/>
        <source>This point can be dragged.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../interaction/InteractiveXSpline.cpp" line="75"/>
        <source>Drag this point or delete it by pressing Del or D.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoadFileTask</name>
    <message>
        <source>The following file could not be loaded:
%1</source>
        <translation type="obsolete">Le fichier suivant ne peut être chargé:
%1</translation>
    </message>
</context>
<context>
    <name>LoadFilesStatusDialog</name>
    <message>
        <location filename="../ui/LoadFilesStatusDialog.ui" line="14"/>
        <source>Some files failed to load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/LoadFilesStatusDialog.ui" line="27"/>
        <source>Loaded successfully: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/LoadFilesStatusDialog.ui" line="87"/>
        <source>Failed to load: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ui/MainWindow.ui" line="232"/>
        <source>Save Project</source>
        <translation>Sauvegarder le Projet</translation>
    </message>
    <message>
        <source>Save this project?</source>
        <translation type="obsolete">Sauvegarder ce projet ?</translation>
    </message>
    <message>
        <source>Insert before ...</source>
        <translation type="obsolete">Insérer avant ...</translation>
    </message>
    <message>
        <source>Insert after ...</source>
        <translation type="obsolete">Insérer après ...</translation>
    </message>
    <message>
        <source>Remove from project ...</source>
        <translation type="obsolete">Retirer du projet ...</translation>
    </message>
    <message>
        <source>Insert here ...</source>
        <translation type="obsolete">Insérer ici ...</translation>
    </message>
    <message>
        <source>Scan Tailor Projects</source>
        <translation type="obsolete">Projets Scan Tailor</translation>
    </message>
    <message>
        <source>Open Project</source>
        <translation type="obsolete">Ouvrir un projet</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="obsolete">Erreur</translation>
    </message>
    <message>
        <source>Unable to open the project file.</source>
        <translation type="obsolete">Impossible d&apos;ouvrir le.fichier du projet.</translation>
    </message>
    <message>
        <source>The project file is broken.</source>
        <translation type="obsolete">Le fichier du projet est endommagé.</translation>
    </message>
    <message>
        <source>Output is not yet possible, as the final size of pages is not yet known.
To determine it, run batch processing at &quot;Select Content&quot; or &quot;Margins&quot;.</source>
        <translation type="obsolete">La sortie n&apos;est pas encore possible, car la taille final des pages n&apos;est pas connue.
Pour la déterminer, lancez le processus de traitement à l&apos;étape &quot;Sélectionner le contenu&quot; ou &quot;Marges&quot;.</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation type="obsolete">Sans Nom</translation>
    </message>
    <message>
        <source>%1 - Scan Tailor %2</source>
        <translation type="obsolete">%1 - Scan Tailor %2</translation>
    </message>
    <message>
        <source>Error saving the project file!</source>
        <translation type="obsolete">Erreur lors de la sauvegarde du fichier du projet !</translation>
    </message>
    <message>
        <source>File to insert</source>
        <translation type="obsolete">Fichier à insérer</translation>
    </message>
    <message>
        <source>Images not in project (%1)</source>
        <translation type="obsolete">Images non présente dans le projet (%1)</translation>
    </message>
    <message>
        <source>Error opening the image file.</source>
        <translation type="obsolete">Erreur à l&apos;ouverture du fichier de l&apos;image.</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="20"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="130"/>
        <source>Keep current page in view.</source>
        <translation>Maintenir l&apos;affichage de la page courante.</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="156"/>
        <source>Use Home, End, PgUp (or Q), PgDown (or W) to navigate between pages.</source>
        <translation>Utiliser Home, Fin, PgUP (ou Q), PgDown (ou W) pour naviguer parmi les pages.</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="185"/>
        <source>Tools</source>
        <translation>Outils</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="196"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="210"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation type="obsolete">Debug</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="227"/>
        <source>Debug Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="235"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="240"/>
        <source>Save Project As ...</source>
        <translation>Enregistrer le projet sous ...</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="245"/>
        <location filename="../ui/MainWindow.ui" line="294"/>
        <source>Next Page</source>
        <translation>Page suivante</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="248"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="256"/>
        <location filename="../ui/MainWindow.ui" line="283"/>
        <source>Previous Page</source>
        <translation>Page précédente</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="259"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="267"/>
        <source>New Project ...</source>
        <translation>Nouveau Projet ...</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="270"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="275"/>
        <source>Open Project ...</source>
        <translation>Ouvrir un Projet ...</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="278"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="286"/>
        <source>Q</source>
        <translation>Q</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="297"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="305"/>
        <source>Close Project</source>
        <translation>Fermer le Projet</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="308"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="313"/>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="316"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="326"/>
        <source>First Page</source>
        <translation>Première Page</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="329"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="334"/>
        <source>Last Page</source>
        <translation>Dernière Page</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="337"/>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="342"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="347"/>
        <source>Fix DPI ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="352"/>
        <source>Relinking ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop batch processing</source>
        <translation type="obsolete">Arrêter le traitement</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="321"/>
        <source>Settings ...</source>
        <translation>Paramètres ...</translation>
    </message>
</context>
<context>
    <name>NewOpenProjectPanel</name>
    <message>
        <location filename="../ui/NewOpenProjectPanel.ui" line="19"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../ui/NewOpenProjectPanel.ui" line="52"/>
        <source>New Project ...</source>
        <translation>Nouveau Projet ...</translation>
    </message>
    <message>
        <location filename="../ui/NewOpenProjectPanel.ui" line="78"/>
        <source>Open Project ...</source>
        <translation>Ouvrir un Projet ...</translation>
    </message>
    <message>
        <location filename="../ui/NewOpenProjectPanel.ui" line="103"/>
        <source>Recent Projects</source>
        <translation>Projets récents</translation>
    </message>
</context>
<context>
    <name>OrientationApplyDialog</name>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="17"/>
        <source>Fix Orientation</source>
        <translation>Fixer l&apos;orientation</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="23"/>
        <source>Apply to</source>
        <translation>Appliquer à</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="29"/>
        <source>This page only (already applied)</source>
        <translation>Cette page uniquement (déjà appliqué)</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="39"/>
        <source>All pages</source>
        <translation>Toutes les pages</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="46"/>
        <source>This page and the following ones</source>
        <translation>Cette page et les suivantes</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="71"/>
        <source>Every other page</source>
        <extracomment>All odd or even pages, depending on the current page being odd or even.</extracomment>
        <translatorcomment>Toutes les pages paires ou impaires, suivant que la page courante soit paire ou impaire</translatorcomment>
        <translation>Toutes les autres pages</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="101"/>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="206"/>
        <source>The current page will be included.</source>
        <translation>Page courante incluse.</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="125"/>
        <source>Selected pages</source>
        <translation>Les pages sélectionnées</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="155"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>Utilisez Ctrl+Clic / MAJ+Click pour sélectionner plusieurs pages.</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="176"/>
        <source>Every other selected page</source>
        <translation>Toutes les autres pages sélectionnées</translation>
    </message>
</context>
<context>
    <name>OrientationOptionsWidget</name>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="13"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="19"/>
        <source>Rotate</source>
        <translation>Rotation</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="40"/>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="56"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="142"/>
        <source>Reset</source>
        <translation>Réinitialiser</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="167"/>
        <source>Scope</source>
        <translation>Cible</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="188"/>
        <source>Apply to ...</source>
        <translation>Appliquer à ...</translation>
    </message>
</context>
<context>
    <name>OutOfMemoryDialog</name>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="14"/>
        <source>Out of memory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="37"/>
        <source>Out of Memory Situation in Scan Tailor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="70"/>
        <source>Possible reasons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="103"/>
        <source>Did you have to fix the DPI of your source images? Are you sure the values you entered were correct?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="123"/>
        <source>Sometimes your source images may have wrong DPI embedded into them. Scan Tailor tries to detect those, but it&apos;s not always easy to tell. You may need to check &quot;Fix DPI even if they look normal&quot; when creating a project and look into &quot;All pages&quot; tab in the &quot;Fix DPI&quot; dialog, which is also accessible from the Tools menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="143"/>
        <source>Is your output DPI set too high? Usually you don&apos;t need it higher than 600.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="174"/>
        <source>What can help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="204"/>
        <source>Fix your DPIs. Learn how to &lt;a href=&quot;http://vimeo.com/12524529&quot;&gt;estimate unknown DPIs&lt;/a&gt;.</source>
        <extracomment>Feel free to change the URL to a localized video / text tutorial.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="224"/>
        <source>If your hardware and operating system are 64-bit capable, consider switching to a 64-bit version of Scan Tailor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="244"/>
        <source>When working with grayscale images, make sure they are really grayscale. If they are actually color images that just happen to look grayscale, convert them to grayscale using some kind of batch image converter. This will both save memory and increase performance.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="264"/>
        <source>As a last resort, you can save some memory by making sure thumbnails are pre-created rather than created on demand. This can be done by slowly scrolling the thumbnail list all the way from top to bottom before starting any real work.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="295"/>
        <source>What won&apos;t help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="325"/>
        <source>Surprisingly, upgrading your RAM won&apos;t help here. The lack of RAM is compensated by the swap mechanism, which makes things slow, but keeps programs running. An out of memory situation means we ran out of memory address space, which has nothing to do with the amount of RAM you have. The only way to increase the memory address space is to go 64-bit hardware, 64-bit operating system and 64-bit Scan Tailor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="361"/>
        <source>Save Project</source>
        <translation type="unfinished">Sauvegarder le Projet</translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="384"/>
        <source>Save Project As ...</source>
        <translation type="unfinished">Enregistrer le projet sous ...</translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="404"/>
        <source>Don&apos;t Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="421"/>
        <source>Project Saved Successfully</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="453"/>
        <source>Please note that while Scan Tailor tries to catch out-of-memory situations and give you the opportunity to save your project, it&apos;s not always possible. This time it succeeded, but the next time it might just crash.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OutputApplyColorsDialog</name>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="17"/>
        <source>Apply Mode</source>
        <translation>Mode d&apos;application</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="23"/>
        <source>Apply to</source>
        <translation>Appliquer à</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="29"/>
        <source>This page only (already applied)</source>
        <translation>Cette page uniquement (déjà appliqué)</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="39"/>
        <source>All pages</source>
        <translation>Toutes les pages</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="46"/>
        <source>This page and the following ones</source>
        <translation>Cette page et les suivantes</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="62"/>
        <source>Selected pages</source>
        <translation>Les pages sélectionnées</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="95"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>Utilisez Ctrl+Clic / MAJ+Click pour sélectionner plusieurs pages.</translation>
    </message>
</context>
<context>
    <name>OutputChangeDewarpingDialog</name>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="17"/>
        <source>Apply Dewarping Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="23"/>
        <source>Mode</source>
        <translation type="unfinished">Mode</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="29"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="42"/>
        <source>Auto (experimental)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="49"/>
        <source>Manual</source>
        <translation type="unfinished">Manuel</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="59"/>
        <source>Scope</source>
        <translation type="unfinished">Cible</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="65"/>
        <source>This page only</source>
        <translation type="unfinished">Cette page uniquement</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="75"/>
        <source>All pages</source>
        <translation type="unfinished">Toutes les pages</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="82"/>
        <source>This page and the following ones</source>
        <translation type="unfinished">Cette page et les suivantes</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="98"/>
        <source>Selected pages</source>
        <translation type="unfinished">Les pages sélectionnées</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="131"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OutputChangeDpiDialog</name>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="17"/>
        <source>Apply Output Resolution</source>
        <translation>Appliquer la résolution de sortie</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="23"/>
        <source>DPI</source>
        <translation>DPI</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="68"/>
        <source>Scope</source>
        <translation>Cible</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="74"/>
        <source>This page only</source>
        <translation>Cette page uniquement</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="91"/>
        <source>This page and the following ones</source>
        <translation>Cette page et les suivantes</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="107"/>
        <source>Selected pages</source>
        <translation>Les pages sélectionnées</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="140"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>Utilisez Ctrl+Clic / MAJ+Click pour sélectionner plusieurs pages.</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="84"/>
        <source>All pages</source>
        <translation>Toutes les pages</translation>
    </message>
</context>
<context>
    <name>OutputOptionsWidget</name>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="14"/>
        <source>Form</source>
        <translation>FORM</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="20"/>
        <source>Output Resolution (DPI)</source>
        <translation>Résolution de sortie (DPI)</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="78"/>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="419"/>
        <source>Change ...</source>
        <translation>Changer ...</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="103"/>
        <source>Mode</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="169"/>
        <source>White margins</source>
        <translation>Marges blanches</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="176"/>
        <source>Equalize illumination</source>
        <translation>Régler l&apos;éclairage</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="361"/>
        <source>Dewarping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="444"/>
        <source>Depth perception</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="533"/>
        <source>No despeckling</source>
        <translation>Pas d&apos;élimination du bruit</translation>
    </message>
    <message>
        <source>Dewarp</source>
        <translation type="obsolete">Dewarp</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="336"/>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="484"/>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="666"/>
        <source>Apply To ...</source>
        <translation>Appliquer à ...</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="509"/>
        <source>Despeckling</source>
        <translation>Élimination du bruit</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="558"/>
        <source>Cautious despeckling</source>
        <translation>Légère élimination du bruit</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="561"/>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="587"/>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="613"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="584"/>
        <source>Normal despeckling</source>
        <translation>Élimination du bruit standard</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="610"/>
        <source>Aggressive despeckling</source>
        <translation>Élimination aggressive du bruit</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="274"/>
        <source>Thinner</source>
        <translation>Éclaircir</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="306"/>
        <source>Thicker</source>
        <translation>Épaissir</translation>
    </message>
</context>
<context>
    <name>PageLayoutApplyDialog</name>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="20"/>
        <source>Apply to</source>
        <translation>Appliquer à</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="26"/>
        <source>This page only (already applied)</source>
        <translation>Cette page uniquement (déjà appliqué)</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="36"/>
        <source>All pages</source>
        <translation>Toutes les pages</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="43"/>
        <source>This page and the following ones</source>
        <translation>Cette page et les suivantes</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="59"/>
        <source>Every other page</source>
        <extracomment>All odd or even pages, depending on the current page being odd or even.</extracomment>
        <translation type="unfinished">Toutes les autres pages</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="89"/>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="194"/>
        <source>The current page will be included.</source>
        <translation type="unfinished">Page courante incluse.</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="110"/>
        <source>Selected pages</source>
        <translation>Les pages sélectionnées</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="143"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>Utilisez Ctrl+Clic / MAJ+Clic pour sélectionner plusieurs pages.</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="164"/>
        <source>Every other selected page</source>
        <translation type="unfinished">Toutes les autres pages sélectionnées</translation>
    </message>
</context>
<context>
    <name>PageLayoutOptionsWidget</name>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="14"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="20"/>
        <source>Margins</source>
        <translation>Définir les Marges</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="42"/>
        <source>Millimeters (mm)</source>
        <translation>Millimètres (mm)</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="47"/>
        <source>Inches (in)</source>
        <translation>Pouces (in)</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="87"/>
        <source>Top</source>
        <translation>Haut</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="100"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="161"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="338"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="361"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="384"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="407"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="430"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="456"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="479"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="502"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="525"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="121"/>
        <source>Bottom</source>
        <translation>Bas</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="138"/>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="185"/>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="244"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="580"/>
        <source>Apply To ...</source>
        <translation>Appliquer à ...</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="269"/>
        <source>Alignment</source>
        <translation>Alignement</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="293"/>
        <source>Match size with other pages</source>
        <translation>Faire correspondre la taille avec les autres les pages</translation>
    </message>
</context>
<context>
    <name>PageSplitModeDialog</name>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="17"/>
        <source>Split Pages</source>
        <translation>Scinder les pages</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="63"/>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="69"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="79"/>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="89"/>
        <source>Scope</source>
        <translation>Cible</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="95"/>
        <source>This page only</source>
        <translation>Cette page uniquement</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="112"/>
        <source>This page and the following ones</source>
        <translation>Cette page et les suivantes</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="128"/>
        <source>Selected pages</source>
        <translation>Les pages sélectionnées</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="161"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>Utilisez Ctrl+Clic / MAJ+Click pour sélectionner plusieurs pages.</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="105"/>
        <source>All pages</source>
        <translation>Toutes les pages</translation>
    </message>
</context>
<context>
    <name>PageSplitOptionsWidget</name>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="20"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="26"/>
        <source>Page Layout</source>
        <translation>Mise en page</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="134"/>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="159"/>
        <source>Change ...</source>
        <translation>Modifier ...</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="184"/>
        <source>Split Line</source>
        <translation>Ligne de découpe</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="214"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="230"/>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
</context>
<context>
    <name>PictureZonePropDialog</name>
    <message>
        <location filename="../filters/output/ui/PictureZonePropDialog.ui" line="14"/>
        <source>Zone Properties</source>
        <translation>Propriétés de la zone</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/PictureZonePropDialog.ui" line="20"/>
        <source>Subtract from all layers</source>
        <translation>Soustraire de toutes les couches</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/PictureZonePropDialog.ui" line="27"/>
        <source>Add to auto layer</source>
        <translation>Ajouter aux couches auto</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/PictureZonePropDialog.ui" line="34"/>
        <source>Subtract from auto layer</source>
        <translation>Soustraire des couches auto</translation>
    </message>
</context>
<context>
    <name>ProjectFilesDialog</name>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="20"/>
        <source>Input Directory</source>
        <translation>Répertoire d&apos;entrée</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="43"/>
        <source>Output Directory</source>
        <translation>Répertoire de sortie</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="obsolete">Erreur</translation>
    </message>
    <message>
        <source>No files in project!</source>
        <translation type="obsolete">Aucun fichier dans le projet !</translation>
    </message>
    <message>
        <source>Input directory is not set or doesn&apos;t exist.</source>
        <translation type="obsolete">Le répertoire d&apos;entrée n&apos;est pas défini ou n&apos;existe pas.</translation>
    </message>
    <message>
        <source>Input and output directories can&apos;t be the same.</source>
        <translation type="obsolete">Le répertoire d&apos;entrée et de sortie ne peuvent être le même.</translation>
    </message>
    <message>
        <source>Create Directory?</source>
        <translation type="obsolete">Créer un Dossier ?</translation>
    </message>
    <message>
        <source>Output directory doesn&apos;t exist.  Create it?</source>
        <translation type="obsolete">Le répertoire de sortie n&apos;existe pas. Le créer ?</translation>
    </message>
    <message>
        <source>Unable to create output directory.</source>
        <translation type="obsolete">Impossible de créer le répertoire de sortie.</translation>
    </message>
    <message>
        <source>Output directory is not set or doesn&apos;t exist.</source>
        <translation type="obsolete">Le répertoire de sortie n&apos;est pas défini ou n&apos;existe pas.</translation>
    </message>
    <message>
        <source>Some of the files failed to load.
Either we don&apos;t support their format, or they are broken.
You should remove them from the project.</source>
        <translation type="obsolete">L&apos;importation de certains fichiers a échouée.
Soit leurs formats n&apos;est pas supporté soit ils sont corrompus.
Vous devrier les retirer du projet.</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="14"/>
        <source>Project Files</source>
        <translation>Fichiers du Projet</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="33"/>
        <location filename="../ui/ProjectFilesDialog.ui" line="52"/>
        <source>Browse</source>
        <translation>Explorer</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="64"/>
        <source>Files Not In Project</source>
        <translation>Fichiers hors projet</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="77"/>
        <location filename="../ui/ProjectFilesDialog.ui" line="159"/>
        <source>Select All</source>
        <translation>Tout sélectionner</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="102"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Add selected files to project.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Ajouter les fichiers sélectionnés au Projet.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="108"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="115"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Remove selected files from project.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Supprimer les fichiers sélectionnés du projet.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="121"/>
        <source>&lt;&lt;</source>
        <translation>&lt;&lt;</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="143"/>
        <source>Files In Project</source>
        <translation>Fichiers du projet</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="171"/>
        <source>Right to left layout (for Hebrew and Arabic)</source>
        <translation>Pagination de Droite à Gauche (pour l&apos;Hébreux et l&apos;Arabe)</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="178"/>
        <source>Fix DPIs, even if they look OK</source>
        <translation>Fixer les DPI, même si cela semble OK</translation>
    </message>
</context>
<context>
    <name>ProjectOpeningContext</name>
    <message>
        <source>Error</source>
        <translation type="obsolete">Erreur</translation>
    </message>
    <message>
        <source>Unable to interpret the project file.</source>
        <translation type="obsolete">Impossible d&apos;interprêter le fichier projet.</translation>
    </message>
</context>
<context>
    <name>RelinkingDialog</name>
    <message>
        <location filename="../ui/RelinkingDialog.ui" line="14"/>
        <source>Relinking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/RelinkingDialog.ui" line="97"/>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/RelinkingDialog.ui" line="100"/>
        <source>...</source>
        <translation type="unfinished">...</translation>
    </message>
</context>
<context>
    <name>RemovePagesDialog</name>
    <message>
        <location filename="../ui/RemovePagesDialog.ui" line="14"/>
        <source>Remove Pages</source>
        <translation>Retirer des pages</translation>
    </message>
    <message>
        <location filename="../ui/RemovePagesDialog.ui" line="57"/>
        <source>Remove %1 page(s) from project?</source>
        <translation>Retirer %1 page(s) du projet ?</translation>
    </message>
    <message>
        <location filename="../ui/RemovePagesDialog.ui" line="72"/>
        <source>Corresponding output files will be deleted, while input files will remain.</source>
        <translation>Les fichiers de sortie correspondants vont être effacés, les fichiers d&apos;entrée seront conservés.</translation>
    </message>
</context>
<context>
    <name>SelectContentApplyDialog</name>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="17"/>
        <source>Select Content</source>
        <translation type="unfinished">Sélectionner le contenu</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="23"/>
        <source>Apply to</source>
        <translation type="unfinished">Appliquer à</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="29"/>
        <source>This page only (already applied)</source>
        <translation type="unfinished">Cette page uniquement (déjà appliqué)</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="39"/>
        <source>All pages</source>
        <translation type="unfinished">Toutes les pages</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="46"/>
        <source>This page and the following ones</source>
        <translation type="unfinished">Cette page et les suivantes</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="71"/>
        <source>Every other page</source>
        <extracomment>All odd or even pages, depending on the current page being odd or even.</extracomment>
        <translation type="unfinished">Toutes les autres pages</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="101"/>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="206"/>
        <source>The current page will be included.</source>
        <translation type="unfinished">Page courante incluse.</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="125"/>
        <source>Selected pages</source>
        <translation type="unfinished">Les pages sélectionnées</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="155"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="176"/>
        <source>Every other selected page</source>
        <translation type="unfinished">Toutes les autres pages sélectionnées</translation>
    </message>
</context>
<context>
    <name>SelectContentOptionsWidget</name>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="13"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="19"/>
        <source>Content Box</source>
        <translation>Boite de contenu</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="38"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="54"/>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="83"/>
        <source>Scope</source>
        <translation type="unfinished">Cible</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="104"/>
        <source>Apply to ...</source>
        <translation type="unfinished">Appliquer à ...</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Compiled without OpenGL support.</source>
        <translation type="obsolete">Compilé sans le support OpenGL.</translation>
    </message>
    <message>
        <source>Your hardware / driver don&apos;t provide the necessary features.</source>
        <translation type="obsolete">Votre matériel / driver n&apos;a pas les caractéristiques requises.</translation>
    </message>
    <message>
        <location filename="../ui/SettingsDialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <location filename="../ui/SettingsDialog.ui" line="20"/>
        <source>Use 3D acceleration for user interface</source>
        <translation>Utilise l&apos;accélération 3D pour l&apos;interface</translation>
    </message>
</context>
<context>
    <name>StageListView</name>
    <message>
        <source>Launch batch processing</source>
        <translation type="obsolete">Lancer le traitement automatique</translation>
    </message>
</context>
<context>
    <name>SystemLoadWidget</name>
    <message>
        <location filename="../ui/SystemLoadWidget.ui" line="14"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../ui/SystemLoadWidget.ui" line="23"/>
        <source>System load</source>
        <translation>Charge système</translation>
    </message>
    <message>
        <location filename="../ui/SystemLoadWidget.ui" line="46"/>
        <location filename="../ui/SystemLoadWidget.ui" line="73"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Minimal</source>
        <translation type="obsolete">Minimal</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="obsolete">Normal</translation>
    </message>
</context>
<context>
    <name>ThumbnailSequence</name>
    <message>
        <source>%1 (page %2)</source>
        <translation type="obsolete">%1 (page %2)</translation>
    </message>
</context>
<context>
    <name>ZoneContextMenuInteraction</name>
    <message>
        <location filename="../zones/ZoneContextMenuInteraction.cpp" line="275"/>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <location filename="../zones/ZoneContextMenuInteraction.cpp" line="265"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../zones/ZoneContextMenuInteraction.cpp" line="249"/>
        <source>Delete confirmation</source>
        <translation>Confirmer la suppression</translation>
    </message>
    <message>
        <location filename="../zones/ZoneContextMenuInteraction.cpp" line="249"/>
        <source>Really delete this zone?</source>
        <translation>Vraiment supprimer cette zone ?</translation>
    </message>
</context>
<context>
    <name>ZoneCreationInteraction</name>
    <message>
        <location filename="../zones/ZoneCreationInteraction.cpp" line="206"/>
        <source>Click to finish this zone.  ESC to cancel.</source>
        <translation>Cliquer pour finir cette zone. ECHAP pour quitter.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneCreationInteraction.cpp" line="208"/>
        <source>Connect first and last points to finish this zone.  ESC to cancel.</source>
        <translation>Connecter le premier et le dernier point pour finir cette zone. ECHAP pour quitter.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneCreationInteraction.cpp" line="211"/>
        <source>Zones need to have at least 3 points.  ESC to cancel.</source>
        <translation>Les Zones doivent avoir obligatoirement 3 points. ECHAP pour quitter.</translation>
    </message>
</context>
<context>
    <name>ZoneDefaultInteraction</name>
    <message>
        <location filename="../zones/ZoneDefaultInteraction.cpp" line="45"/>
        <source>Drag the vertex.</source>
        <translation>Faites glisser le &quot;Sommet (Vertex)&quot;.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneDefaultInteraction.cpp" line="46"/>
        <source>Click to create a new vertex here.</source>
        <translation>Cliquer ici pour créer un nouveau &quot;sommet (vertex)&quot;.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneDefaultInteraction.cpp" line="47"/>
        <source>Right click to edit zone properties.</source>
        <translation>Clic-droit pour éditer les propriétés de la zone.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneDefaultInteraction.cpp" line="49"/>
        <source>Click to start creating a new picture zone.</source>
        <translation>Cliquer pour débuter la création d&apos;une nouvelle zone image.</translation>
    </message>
</context>
<context>
    <name>ZoneVertexDragInteraction</name>
    <message>
        <location filename="../zones/ZoneVertexDragInteraction.cpp" line="160"/>
        <source>Merge these two vertices.</source>
        <translation>Fusionner ces deux &quot;sommets (vertices)&quot;.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneVertexDragInteraction.cpp" line="162"/>
        <source>Move the vertex to one of its neighbors to merge them.</source>
        <translation>Déplacez le &quot;sommet (vertex)&quot; vers l&apos;un de ces voisins pour les fusionner.</translation>
    </message>
</context>
<context>
    <name>deskew::Filter</name>
    <message>
        <location filename="../filters/deskew/Filter.cpp" line="57"/>
        <source>Deskew</source>
        <translation>Redresser</translation>
    </message>
</context>
<context>
    <name>deskew::ImageView</name>
    <message>
        <location filename="../filters/deskew/ImageView.cpp" line="62"/>
        <source>Use Ctrl+Wheel to rotate or Ctrl+Shift+Wheel for finer rotation.</source>
        <translation>Utiliser Ctrl+molette souris pour effectuer la rotation ou Ctrl+MAJ+molette souris pour une rotation plus fine.</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ImageView.cpp" line="65"/>
        <source>Drag this handle to rotate the image.</source>
        <translation>Faites glisser cette poignée pour faire pivoter l&apos;image.</translation>
    </message>
</context>
<context>
    <name>deskew::OptionsWidget</name>
    <message>
        <location filename="../filters/deskew/OptionsWidget.cpp" line="69"/>
        <source>Apply Deskew</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>fix_orientation::ApplyDialog</name>
    <message>
        <location filename="../filters/fix_orientation/ApplyDialog.cpp" line="53"/>
        <source>Can&apos;t do: more than one group is selected.</source>
        <translation type="unfinished">Impossible d&apos;appliquer : plus d&apos;un groupe est sélectionné.</translation>
    </message>
</context>
<context>
    <name>fix_orientation::Filter</name>
    <message>
        <location filename="../filters/fix_orientation/Filter.cpp" line="64"/>
        <source>Fix Orientation</source>
        <translation>Fixer l&apos;Orientation</translation>
    </message>
</context>
<context>
    <name>output::ChangeDpiDialog</name>
    <message>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="72"/>
        <source>Custom</source>
        <translation>Personnaliser</translation>
    </message>
    <message>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="131"/>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="140"/>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="148"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="132"/>
        <source>DPI is not set.</source>
        <translation>Le DPI n&apos;est pas défini.</translation>
    </message>
    <message>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="141"/>
        <source>DPI is too low!</source>
        <translation>DPI trop faible !</translation>
    </message>
    <message>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="149"/>
        <source>DPI is too high!</source>
        <translation>DPI trop élevé !</translation>
    </message>
</context>
<context>
    <name>output::FillZoneEditor</name>
    <message>
        <location filename="../filters/output/FillZoneEditor.cpp" line="226"/>
        <source>Pick color</source>
        <translation>Choisir la couleur</translation>
    </message>
</context>
<context>
    <name>output::Filter</name>
    <message>
        <location filename="../filters/output/Filter.cpp" line="63"/>
        <source>Output</source>
        <translation>Sortie</translation>
    </message>
</context>
<context>
    <name>output::OptionsWidget</name>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="63"/>
        <source>Black and White</source>
        <translation>Noir et blanc</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="64"/>
        <source>Color / Grayscale</source>
        <translation>Couleur / Niveaux de gris</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="65"/>
        <source>Mixed</source>
        <translation>Mixte</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="407"/>
        <source>Apply Despeckling Level</source>
        <translation>Appliquer le réglage d&apos;élimination du bruit</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="487"/>
        <source>Apply Depth Perception</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="660"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="663"/>
        <source>Auto</source>
        <translation type="unfinished">Auto</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="666"/>
        <source>Manual</source>
        <translation type="unfinished">Manuel</translation>
    </message>
</context>
<context>
    <name>output::Task::UiUpdater</name>
    <message>
        <location filename="../filters/output/Task.cpp" line="506"/>
        <source>Picture zones are only available in Mixed mode.</source>
        <translation>Les zones images sont uniquement disponnible dans le mode Mixte.</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="558"/>
        <source>Despeckling can&apos;t be done in Color / Grayscale mode.</source>
        <translation>l&apos;élimination du bruit ne peut être effectuée en mode Couleur / Niveau de gris.</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="575"/>
        <source>Output</source>
        <translation>Sortie</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="576"/>
        <source>Picture Zones</source>
        <translation>Zone images</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="577"/>
        <source>Fill Zones</source>
        <translation>Zones de remplissage</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="578"/>
        <source>Dewarping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="579"/>
        <source>Despeckling</source>
        <translation>Élimination du bruit</translation>
    </message>
</context>
<context>
    <name>page_layout::ApplyDialog</name>
    <message>
        <location filename="../filters/page_layout/ApplyDialog.cpp" line="51"/>
        <source>Can&apos;t do: more than one group is selected.</source>
        <translation type="unfinished">Impossible d&apos;appliquer : plus d&apos;un groupe est sélectionné.</translation>
    </message>
</context>
<context>
    <name>page_layout::Filter</name>
    <message>
        <location filename="../filters/page_layout/Filter.cpp" line="67"/>
        <source>Natural order</source>
        <translation>Ordre naturel</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/Filter.cpp" line="68"/>
        <source>Order by increasing width</source>
        <translation>Trier par largeur croissante</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/Filter.cpp" line="69"/>
        <source>Order by increasing height</source>
        <translation>Trier par hauteur croissante</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/Filter.cpp" line="79"/>
        <source>Margins</source>
        <translation>Définir les Marges</translation>
    </message>
</context>
<context>
    <name>page_layout::ImageView</name>
    <message>
        <location filename="../filters/page_layout/ImageView.cpp" line="76"/>
        <source>Resize margins by dragging any of the solid lines.</source>
        <translation>Redimensionnez les marges en faisant glisser les traits pleins.</translation>
    </message>
</context>
<context>
    <name>page_layout::OptionsWidget</name>
    <message>
        <location filename="../filters/page_layout/OptionsWidget.cpp" line="310"/>
        <source>Apply Margins</source>
        <translation>Appliquer les Marges</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/OptionsWidget.cpp" line="325"/>
        <source>Apply Alignment</source>
        <translation>Appliquer l&apos;Alignement</translation>
    </message>
</context>
<context>
    <name>page_split::Filter</name>
    <message>
        <location filename="../filters/page_split/Filter.cpp" line="65"/>
        <source>Natural order</source>
        <translation type="unfinished">Ordre naturel</translation>
    </message>
    <message>
        <location filename="../filters/page_split/Filter.cpp" line="66"/>
        <source>Order by split type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/page_split/Filter.cpp" line="76"/>
        <source>Split Pages</source>
        <translation>Scinder les Pages</translation>
    </message>
</context>
<context>
    <name>page_split::ImageView</name>
    <message>
        <location filename="../filters/page_split/ImageView.cpp" line="85"/>
        <source>Drag the line or the handles.</source>
        <translation type="unfinished">Faites glisser la ligne de découpe ou les poignées.</translation>
    </message>
</context>
<context>
    <name>page_split::OptionsWidget</name>
    <message>
        <location filename="../filters/page_split/OptionsWidget.cpp" line="116"/>
        <location filename="../filters/page_split/OptionsWidget.cpp" line="208"/>
        <location filename="../filters/page_split/OptionsWidget.cpp" line="301"/>
        <source>Set manually</source>
        <translation>Définir manuellement</translation>
    </message>
    <message>
        <location filename="../filters/page_split/OptionsWidget.cpp" line="165"/>
        <location filename="../filters/page_split/OptionsWidget.cpp" line="298"/>
        <source>Auto detected</source>
        <translation>Détection automatique</translation>
    </message>
</context>
<context>
    <name>page_split::UnremoveButton</name>
    <message>
        <location filename="../filters/page_split/UnremoveButton.cpp" line="38"/>
        <source>Restore removed page.</source>
        <translation>Rétablir la page supprimée.</translation>
    </message>
</context>
<context>
    <name>select_content::ApplyDialog</name>
    <message>
        <location filename="../filters/select_content/ApplyDialog.cpp" line="53"/>
        <source>Can&apos;t do: more than one group is selected.</source>
        <translation type="unfinished">Impossible d&apos;appliquer : plus d&apos;un groupe est sélectionné.</translation>
    </message>
</context>
<context>
    <name>select_content::Filter</name>
    <message>
        <location filename="../filters/select_content/Filter.cpp" line="59"/>
        <source>Natural order</source>
        <translation>Ordre naturel</translation>
    </message>
    <message>
        <location filename="../filters/select_content/Filter.cpp" line="60"/>
        <source>Order by increasing width</source>
        <translation>Trier par largeur croissante</translation>
    </message>
    <message>
        <location filename="../filters/select_content/Filter.cpp" line="61"/>
        <source>Order by increasing height</source>
        <translation>Trier par hauteur croissante</translation>
    </message>
    <message>
        <location filename="../filters/select_content/Filter.cpp" line="71"/>
        <source>Select Content</source>
        <translation>Sélectionner le contenu</translation>
    </message>
</context>
<context>
    <name>select_content::ImageView</name>
    <message>
        <location filename="../filters/select_content/ImageView.cpp" line="58"/>
        <source>Use the context menu to enable / disable the content box.</source>
        <translation>Utilisez le menu contextuel (clic droit) pour créer / supprimer la &quot;boite de contenu&quot;.</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ImageView.cpp" line="61"/>
        <source>Drag lines or corners to resize the content box.</source>
        <translation>Faites glisser les lignes ou les coins pour redimensionner la &quot;boite de contenu&quot;.</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ImageView.cpp" line="107"/>
        <source>Create Content Box</source>
        <translation>Créer une &quot;boite de contenu&quot;</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ImageView.cpp" line="108"/>
        <source>Remove Content Box</source>
        <translation>Supprimer la &quot;boite de contenu&quot;</translation>
    </message>
</context>
</TS>
